@@ -17,17 +17,17 @@
 #include "../src/specialmailcollectionstesting_p.h"
 #include "specialcollectionattribute.h"
 #include "specialcollections.h"
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
+#include <Akonadi/CollectionCreateJob>
+#include <Akonadi/CollectionDeleteJob>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/ServerManager>
 #include <KLocalizedString>
 #include <QStandardPaths>
-#include <agentinstance.h>
-#include <agentmanager.h>
-#include <collectioncreatejob.h>
-#include <collectiondeletejob.h>
-#include <collectionfetchjob.h>
-#include <collectionmodifyjob.h>
+#include <akonadi/qtest_akonadi.h>
 #include <control.h>
-#include <qtest_akonadi.h>
-#include <servermanager.h>
 #include <specialmailcollections.h>
 
 using namespace Akonadi;
@@ -486,7 +486,7 @@ void LocalFoldersTest::testDefaultResourceJob()
     SpecialMailCollectionsTesting *scmt = SpecialMailCollectionsTesting::_t_self();
     scmt->_t_setDefaultResourceId(QLatin1String("akonadi_maildir_resource"));
 
-    // Initially the defaut maildir does not exist.
+    // Initially the default maildir does not exist.
     QVERIFY(!QFile::exists(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/local-mail")));
 
     // Run the job.
